# Changelog

Human-readable list of changes.


## [Unreleased]

## [0.1.4] - 2020-06-20

### Added

- Outlook 2019 friendly HTML template
- CSV template
- A list of tool-provided templates in the `--help`
- A human-readable CHANGELOG.md file

### Changed

- How module templates are named. The new default is "html" replacing "default.html"
- Fix in the documentation links and LICENSE formatting


## [0.1.3] - 2020-05-17

### Added

- Docker Hub support for automated builds
- Containers available at https://hub.docker.com/r/giacomolozito/uptime-reporting


## [0.1.2] - 2020-05-16

### Changed

- Fix for the default value of the `--report-jinja-flags` parameter


## [0.1.1] - 2020-05-16

### Added
- Initial version
